{ "account": { "id": 11, "master_id": 11, "type": 3, "logo": "https://s3.amazonaws.com/files.wheniwork.com/logos/16434.gif", "company": "123 Company", "subdomain": "123-company", "enabled": true, "bad_credit_card": false, "plan_expires": "Sun, 14 Feb 2016 00:00:00 -0600", "features": "[\"all\",\"locations\",\"sites\", ...]", "timezone_id": "11", "timezone_name": "America/Chicago", "settings": "...", "place": { "business_name": "When I Work", "address": "60 Plato Blvd, St Paul, MN 55107, United States", "place_id": "ChIJYfRBzjfVslIRQLB018IGX3o", "place_type": "point_of_interest,establishment", "latitude": "44.93739849", "longitude": "-93.0843011" } } }